import os
from docker_buildtool import docker_build, dockerfile, rsync

class Builder(object):
    def __init__(self, dockerfile, image, variables=None, fetch=False, default_build_root=None, quiet=False):
        self.dockerfile = dockerfile
        self.image = image
        self.fetch = fetch

        if self.image is None:
            docker_repo = None
            tag = None
        else:
            parsed_tag = self.image.split(':')
            if len(parsed_tag) > 1:
                docker_repo = parsed_tag[0]
                tag = parsed_tag[1]
            else:
                docker_repo = parsed_tag[0]
                tag = 'latest'

        self.docker_repo = docker_repo
        self.tag = tag

        if variables is None:
            variables = {}
        self.variables = variables
        self.default_build_root = default_build_root
        self.quiet = quiet

        self.spec = self.prepare()

    def prepare(self):
        return dockerfile.DockerfileBuildSpec(self.dockerfile)

    def run(self, dryrun, docker_args=[], use_rsync=False):
        if self.spec.has_frontmatter:
            build_root = self.spec.build_root
        else:
            build_root = self.default_build_root
        build = docker_build.DockerBuild(
            dockerfile=self.spec.dockerfile,
            build_root=build_root,
            include=self.spec.include,
            workdir=self.spec.workdir,
            ignore=self.spec.ignore,
            docker_repo=self.docker_repo,
            tag=self.tag,
            default_ignore=self.spec.default_ignore,
            include_version_file=self.spec.include_version_file,
            variables=self.variables,
            fetch=self.fetch,
            no_ignore_override=self.spec.no_ignore_override,
            quiet=self.quiet,
        )
        if use_rsync or os.getenv('DOCKER_BUILDTOOL_RSYNC'):
            rsync.remote_build(dryrun, build, docker_args=docker_args)
        else:
            build.run(dryrun=dryrun, docker_args=docker_args)
